@@ -5,12 +5,13 @@
 
 namespace test {
 
-enum class meta_traits {
-    none = 0x0000,
-    one = 0x0001,
-    two = 0x0002,
-    three = 0x0100,
-    _entt_enum_as_bitmask
+enum class meta_traits : std::uint8_t {
+    none = 0x00,
+    one = 0x01,
+    two = 0x02,
+    three = 0x04,
+    all = 0xFF,
+    _entt_enum_as_bitmask = all
 };
 
 } // namespace test
