@@ -57,6 +57,24 @@ TEST(Any, Empty) {
     ASSERT_EQ(any.data(), nullptr);
 }
 
+TEST(Any, HasValue) {
+    entt::any any{};
+
+    ASSERT_FALSE(any.has_value());
+    ASSERT_FALSE(any.has_value(entt::type_id<char>()));
+    ASSERT_FALSE(any.has_value(entt::type_id<int>()));
+    ASSERT_FALSE(any.has_value<char>());
+    ASSERT_FALSE(any.has_value<int>());
+
+    any = 2;
+
+    ASSERT_TRUE(any.has_value());
+    ASSERT_FALSE(any.has_value(entt::type_id<char>()));
+    ASSERT_TRUE(any.has_value(entt::type_id<int>()));
+    ASSERT_FALSE(any.has_value<char>());
+    ASSERT_TRUE(any.has_value<int>());
+}
+
 TEST(Any, SBO) {
     entt::any any{'c'};
 
@@ -88,7 +106,7 @@ TEST(Any, SBOInPlaceConstruction) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<int>(any), 2);
 
@@ -97,7 +115,7 @@ TEST(Any, SBOInPlaceConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::ref);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(other), 2);
     ASSERT_EQ(other.data(), any.data());
 }
@@ -109,7 +127,7 @@ TEST(Any, SBOInPlaceNullptrConstruction) {
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
 }
 
 TEST(Any, SBOInPlaceTypeConstruction) {
@@ -118,7 +136,7 @@ TEST(Any, SBOInPlaceTypeConstruction) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<int>(any), 2);
 
@@ -127,7 +145,7 @@ TEST(Any, SBOInPlaceTypeConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::ref);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(other), 2);
     ASSERT_EQ(other.data(), any.data());
 }
@@ -139,7 +157,7 @@ TEST(Any, SBOAsRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::ref);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
 
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<const int>(&any), &value);
@@ -158,7 +176,7 @@ TEST(Any, SBOAsRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::ref);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(&any), &value);
 
     auto other = any.as_ref();
@@ -166,7 +184,7 @@ TEST(Any, SBOAsRefConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::ref);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(other), 2);
     ASSERT_EQ(other.data(), any.data());
 }
@@ -178,7 +196,7 @@ TEST(Any, SBOAsConstRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::cref);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
 
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<const int>(&any), &value);
@@ -197,7 +215,7 @@ TEST(Any, SBOAsConstRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::cref);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<const int>(&any), &value);
 
     auto other = any.as_ref();
@@ -205,7 +223,7 @@ TEST(Any, SBOAsConstRefConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::cref);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(other), 2);
     ASSERT_EQ(other.data(), any.data());
 }
@@ -218,7 +236,7 @@ TEST(Any, SBOCopyConstruction) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<int>(other), 2);
 }
@@ -233,7 +251,7 @@ TEST(Any, SBOCopyAssignment) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<int>(other), 2);
 }
@@ -247,7 +265,7 @@ TEST(Any, SBOSelfCopyAssignment) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<int>(any), 2);
 }
@@ -262,7 +280,7 @@ TEST(Any, SBOMoveConstruction) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<int>(other), 2);
 }
@@ -278,22 +296,22 @@ TEST(Any, SBOMoveAssignment) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(other.type(), entt::type_id<int>());
+    ASSERT_EQ(other.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<int>(other), 2);
 }
 
-TEST(AnyDeathTest, SBOSelfMoveAssignment) {
+TEST(Any, SBOSelfMoveAssignment) {
     entt::any any{2};
 
     // avoid warnings due to self-assignment
     any = std::move(*&any);
 
-    ASSERT_FALSE(any);
-    ASSERT_FALSE(any.owner());
-    ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
-    ASSERT_EQ(any.data(), nullptr);
+    ASSERT_TRUE(any);
+    ASSERT_TRUE(any.owner());
+    ASSERT_EQ(any.policy(), entt::any_policy::embedded);
+    ASSERT_EQ(any.info(), entt::type_id<int>());
+    ASSERT_EQ(entt::any_cast<int>(any), 2);
 }
 
 TEST(Any, SBODirectAssignment) {
@@ -303,7 +321,7 @@ TEST(Any, SBODirectAssignment) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<int>(any), 2);
 }
@@ -407,7 +425,7 @@ TEST(Any, NoSBOInPlaceConstruction) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(any), (fat{.1, .2, .3, .4}));
 
@@ -416,7 +434,7 @@ TEST(Any, NoSBOInPlaceConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::ref);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(other), (fat{.1, .2, .3, .4}));
     ASSERT_EQ(other.data(), any.data());
 }
@@ -428,7 +446,7 @@ TEST(Any, NoSBOInPlaceNullptrConstruction) {
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
 }
 
 TEST(Any, NoSBOInPlaceTypeConstruction) {
@@ -438,7 +456,7 @@ TEST(Any, NoSBOInPlaceTypeConstruction) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(any), instance);
 
@@ -447,7 +465,7 @@ TEST(Any, NoSBOInPlaceTypeConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::ref);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(other), (fat{.1, .2, .3, .4}));
     ASSERT_EQ(other.data(), any.data());
 }
@@ -459,7 +477,7 @@ TEST(Any, NoSBOAsRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::ref);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
 
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<const fat>(&any), &instance);
@@ -478,7 +496,7 @@ TEST(Any, NoSBOAsRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::ref);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(&any), &instance);
 
     auto other = any.as_ref();
@@ -486,7 +504,7 @@ TEST(Any, NoSBOAsRefConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::ref);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(other), (fat{.1, .2, .3, .4}));
     ASSERT_EQ(other.data(), any.data());
 }
@@ -498,7 +516,7 @@ TEST(Any, NoSBOAsConstRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::cref);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
 
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<const fat>(&any), &instance);
@@ -517,7 +535,7 @@ TEST(Any, NoSBOAsConstRefConstruction) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::cref);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<const fat>(&any), &instance);
 
     auto other = any.as_ref();
@@ -525,7 +543,7 @@ TEST(Any, NoSBOAsConstRefConstruction) {
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::cref);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(other), (fat{.1, .2, .3, .4}));
     ASSERT_EQ(other.data(), any.data());
 }
@@ -539,7 +557,7 @@ TEST(Any, NoSBOCopyConstruction) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(other), instance);
 }
@@ -555,7 +573,7 @@ TEST(Any, NoSBOCopyAssignment) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(other), instance);
 }
@@ -570,7 +588,7 @@ TEST(Any, NoSBOSelfCopyAssignment) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(any), instance);
 }
@@ -586,7 +604,7 @@ TEST(Any, NoSBOMoveConstruction) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(other), instance);
 }
@@ -603,23 +621,23 @@ TEST(Any, NoSBOMoveAssignment) {
     ASSERT_TRUE(other);
     ASSERT_TRUE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(other.type(), entt::type_id<fat>());
+    ASSERT_EQ(other.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(other), instance);
 }
 
-TEST(AnyDeathTest, NoSBOSelfMoveAssignment) {
+TEST(Any, NoSBOSelfMoveAssignment) {
     const fat instance{.1, .2, .3, .4};
     entt::any any{instance};
 
     // avoid warnings due to self-assignment
     any = std::move(*&any);
 
-    ASSERT_FALSE(any);
-    ASSERT_FALSE(any.owner());
-    ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
-    ASSERT_EQ(any.data(), nullptr);
+    ASSERT_TRUE(any);
+    ASSERT_TRUE(any.owner());
+    ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
+    ASSERT_EQ(entt::any_cast<fat>(any), instance);
 }
 
 TEST(Any, NoSBODirectAssignment) {
@@ -630,7 +648,7 @@ TEST(Any, NoSBODirectAssignment) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(any.type(), entt::type_id<fat>());
+    ASSERT_EQ(any.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(any), instance);
 }
@@ -747,7 +765,7 @@ TEST(Any, VoidInPlaceTypeConstruction) {
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
     ASSERT_EQ(entt::any_cast<int>(&any), nullptr);
 }
 
@@ -759,7 +777,7 @@ TEST(Any, VoidCopyConstruction) {
     ASSERT_FALSE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::empty);
-    ASSERT_EQ(other.type(), entt::type_id<void>());
+    ASSERT_EQ(other.info(), entt::type_id<void>());
     ASSERT_EQ(entt::any_cast<int>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
 }
@@ -774,7 +792,7 @@ TEST(Any, VoidCopyAssignment) {
     ASSERT_FALSE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::empty);
-    ASSERT_EQ(other.type(), entt::type_id<void>());
+    ASSERT_EQ(other.info(), entt::type_id<void>());
     ASSERT_EQ(entt::any_cast<int>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
 }
@@ -788,7 +806,7 @@ TEST(Any, VoidSelfCopyAssignment) {
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
     ASSERT_EQ(entt::any_cast<int>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
 }
@@ -803,7 +821,7 @@ TEST(Any, VoidMoveConstruction) {
     ASSERT_FALSE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::empty);
-    ASSERT_EQ(other.type(), entt::type_id<void>());
+    ASSERT_EQ(other.info(), entt::type_id<void>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
 }
 
@@ -818,11 +836,11 @@ TEST(Any, VoidMoveAssignment) {
     ASSERT_FALSE(other);
     ASSERT_FALSE(other.owner());
     ASSERT_EQ(other.policy(), entt::any_policy::empty);
-    ASSERT_EQ(other.type(), entt::type_id<void>());
+    ASSERT_EQ(other.info(), entt::type_id<void>());
     ASSERT_EQ(entt::any_cast<double>(&other), nullptr);
 }
 
-TEST(AnyDeathTest, VoidSelfMoveAssignment) {
+TEST(Any, VoidSelfMoveAssignment) {
     entt::any any{std::in_place_type<void>};
 
     // avoid warnings due to self-assignment
@@ -831,7 +849,7 @@ TEST(AnyDeathTest, VoidSelfMoveAssignment) {
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
     ASSERT_EQ(any.data(), nullptr);
 }
 
@@ -919,7 +937,7 @@ TEST(Any, Emplace) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<double>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<int>(any), 2);
 }
@@ -931,7 +949,7 @@ TEST(Any, EmplaceVoid) {
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
 }
 
 TEST(Any, Reset) {
@@ -940,14 +958,14 @@ TEST(Any, Reset) {
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
 
     any.reset();
 
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
 
     int value = 2;
     any.emplace<int &>(value);
@@ -955,14 +973,14 @@ TEST(Any, Reset) {
     ASSERT_TRUE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::ref);
-    ASSERT_EQ(any.type(), entt::type_id<int>());
+    ASSERT_EQ(any.info(), entt::type_id<int>());
 
     any.reset();
 
     ASSERT_FALSE(any);
     ASSERT_FALSE(any.owner());
     ASSERT_EQ(any.policy(), entt::any_policy::empty);
-    ASSERT_EQ(any.type(), entt::type_id<void>());
+    ASSERT_EQ(any.info(), entt::type_id<void>());
 }
 
 TEST(Any, SBOSwap) {
@@ -977,8 +995,8 @@ TEST(Any, SBOSwap) {
     ASSERT_EQ(lhs.policy(), entt::any_policy::embedded);
     ASSERT_EQ(rhs.policy(), entt::any_policy::embedded);
 
-    ASSERT_EQ(lhs.type(), entt::type_id<int>());
-    ASSERT_EQ(rhs.type(), entt::type_id<char>());
+    ASSERT_EQ(lhs.info(), entt::type_id<int>());
+    ASSERT_EQ(rhs.info(), entt::type_id<char>());
     ASSERT_EQ(entt::any_cast<char>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<int>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<int>(lhs), 2);
@@ -1029,8 +1047,8 @@ TEST(Any, SBOWithNoSBOSwap) {
     ASSERT_EQ(lhs.policy(), entt::any_policy::embedded);
     ASSERT_EQ(rhs.policy(), entt::any_policy::dynamic);
 
-    ASSERT_EQ(lhs.type(), entt::type_id<char>());
-    ASSERT_EQ(rhs.type(), entt::type_id<fat>());
+    ASSERT_EQ(lhs.info(), entt::type_id<char>());
+    ASSERT_EQ(rhs.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(lhs), 'c');
@@ -1050,8 +1068,8 @@ TEST(Any, SBOWithRefSwap) {
     ASSERT_EQ(lhs.policy(), entt::any_policy::embedded);
     ASSERT_EQ(rhs.policy(), entt::any_policy::ref);
 
-    ASSERT_EQ(lhs.type(), entt::type_id<char>());
-    ASSERT_EQ(rhs.type(), entt::type_id<int>());
+    ASSERT_EQ(lhs.info(), entt::type_id<char>());
+    ASSERT_EQ(rhs.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(lhs), 'c');
@@ -1072,8 +1090,8 @@ TEST(Any, SBOWithConstRefSwap) {
     ASSERT_EQ(lhs.policy(), entt::any_policy::embedded);
     ASSERT_EQ(rhs.policy(), entt::any_policy::cref);
 
-    ASSERT_EQ(lhs.type(), entt::type_id<char>());
-    ASSERT_EQ(rhs.type(), entt::type_id<int>());
+    ASSERT_EQ(lhs.info(), entt::type_id<char>());
+    ASSERT_EQ(rhs.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(lhs), 'c');
@@ -1091,7 +1109,7 @@ TEST(Any, SBOWithEmptySwap) {
     ASSERT_FALSE(lhs);
     ASSERT_FALSE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::empty);
-    ASSERT_EQ(rhs.type(), entt::type_id<char>());
+    ASSERT_EQ(rhs.info(), entt::type_id<char>());
     ASSERT_EQ(entt::any_cast<char>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(rhs), 'c');
@@ -1101,7 +1119,7 @@ TEST(Any, SBOWithEmptySwap) {
     ASSERT_FALSE(rhs);
     ASSERT_TRUE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(lhs.type(), entt::type_id<char>());
+    ASSERT_EQ(lhs.info(), entt::type_id<char>());
     ASSERT_EQ(entt::any_cast<double>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(lhs), 'c');
@@ -1116,7 +1134,7 @@ TEST(Any, SBOWithVoidSwap) {
     ASSERT_FALSE(lhs);
     ASSERT_FALSE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::empty);
-    ASSERT_EQ(rhs.type(), entt::type_id<char>());
+    ASSERT_EQ(rhs.info(), entt::type_id<char>());
     ASSERT_EQ(entt::any_cast<char>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(rhs), 'c');
@@ -1126,7 +1144,7 @@ TEST(Any, SBOWithVoidSwap) {
     ASSERT_FALSE(rhs);
     ASSERT_TRUE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::embedded);
-    ASSERT_EQ(lhs.type(), entt::type_id<char>());
+    ASSERT_EQ(lhs.info(), entt::type_id<char>());
     ASSERT_EQ(entt::any_cast<double>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<char>(lhs), 'c');
@@ -1145,8 +1163,8 @@ TEST(Any, NoSBOWithRefSwap) {
     ASSERT_EQ(lhs.policy(), entt::any_policy::dynamic);
     ASSERT_EQ(rhs.policy(), entt::any_policy::ref);
 
-    ASSERT_EQ(lhs.type(), entt::type_id<fat>());
-    ASSERT_EQ(rhs.type(), entt::type_id<int>());
+    ASSERT_EQ(lhs.info(), entt::type_id<fat>());
+    ASSERT_EQ(rhs.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(lhs), (fat{.1, .2, .3, .4}));
@@ -1167,8 +1185,8 @@ TEST(Any, NoSBOWithConstRefSwap) {
     ASSERT_EQ(lhs.policy(), entt::any_policy::dynamic);
     ASSERT_EQ(rhs.policy(), entt::any_policy::cref);
 
-    ASSERT_EQ(lhs.type(), entt::type_id<fat>());
-    ASSERT_EQ(rhs.type(), entt::type_id<int>());
+    ASSERT_EQ(lhs.info(), entt::type_id<fat>());
+    ASSERT_EQ(rhs.info(), entt::type_id<int>());
     ASSERT_EQ(entt::any_cast<int>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(lhs), (fat{.1, .2, .3, .4}));
@@ -1186,7 +1204,7 @@ TEST(Any, NoSBOWithEmptySwap) {
     ASSERT_FALSE(lhs);
     ASSERT_FALSE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::empty);
-    ASSERT_EQ(rhs.type(), entt::type_id<fat>());
+    ASSERT_EQ(rhs.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(rhs), (fat{.1, .2, .3, .4}));
@@ -1196,7 +1214,7 @@ TEST(Any, NoSBOWithEmptySwap) {
     ASSERT_FALSE(rhs);
     ASSERT_TRUE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(lhs.type(), entt::type_id<fat>());
+    ASSERT_EQ(lhs.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(lhs), (fat{.1, .2, .3, .4}));
@@ -1211,7 +1229,7 @@ TEST(Any, NoSBOWithVoidSwap) {
     ASSERT_FALSE(lhs);
     ASSERT_FALSE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::empty);
-    ASSERT_EQ(rhs.type(), entt::type_id<fat>());
+    ASSERT_EQ(rhs.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<fat>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<double>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(rhs), (fat{.1, .2, .3, .4}));
@@ -1221,7 +1239,7 @@ TEST(Any, NoSBOWithVoidSwap) {
     ASSERT_FALSE(rhs);
     ASSERT_TRUE(lhs.owner());
     ASSERT_EQ(lhs.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(lhs.type(), entt::type_id<fat>());
+    ASSERT_EQ(lhs.info(), entt::type_id<fat>());
     ASSERT_EQ(entt::any_cast<double>(&lhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(&rhs), nullptr);
     ASSERT_EQ(entt::any_cast<fat>(lhs), (fat{.1, .2, .3, .4}));
@@ -1443,6 +1461,53 @@ TEST(Any, CompareVoid) {
     ASSERT_FALSE(entt::any{} != any);
 }
 
+TEST(Any, Data) {
+    entt::any any{2};
+    const auto &cany = any;
+    entt::any empty{};
+
+    ASSERT_EQ(empty.data(), nullptr);
+    ASSERT_NE(any.data(), nullptr);
+    ASSERT_NE(cany.data(), nullptr);
+    ASSERT_NE(any.as_ref().data(), nullptr);
+    ASSERT_EQ(cany.as_ref().data(), nullptr);
+
+    ASSERT_EQ(empty.data<char>(), nullptr);
+    ASSERT_EQ(any.data<char>(), nullptr);
+    ASSERT_EQ(cany.data<char>(), nullptr);
+    ASSERT_EQ(any.data<const char>(), nullptr);
+    ASSERT_EQ(cany.data<const char>(), nullptr);
+    ASSERT_EQ(any.as_ref().data<char>(), nullptr);
+    ASSERT_EQ(cany.as_ref().data<char>(), nullptr);
+    ASSERT_EQ(any.as_ref().data<const char>(), nullptr);
+    ASSERT_EQ(cany.as_ref().data<const char>(), nullptr);
+
+    ASSERT_EQ(empty.data<int>(), nullptr);
+    ASSERT_NE(any.data<int>(), nullptr);
+    ASSERT_NE(cany.data<int>(), nullptr);
+    ASSERT_NE(any.data<const int>(), nullptr);
+    ASSERT_NE(cany.data<const int>(), nullptr);
+    ASSERT_NE(any.as_ref().data<int>(), nullptr);
+    ASSERT_EQ(cany.as_ref().data<int>(), nullptr);
+    ASSERT_NE(any.as_ref().data<const int>(), nullptr);
+    ASSERT_NE(cany.as_ref().data<const int>(), nullptr);
+
+    const auto &char_info = entt::type_id<char>();
+    const auto &int_info = entt::type_id<int>();
+
+    ASSERT_EQ(empty.data(char_info), nullptr);
+    ASSERT_EQ(any.data(char_info), nullptr);
+    ASSERT_EQ(cany.data(char_info), nullptr);
+    ASSERT_EQ(any.as_ref().data(char_info), nullptr);
+    ASSERT_EQ(cany.as_ref().data(char_info), nullptr);
+
+    ASSERT_EQ(empty.data(int_info), nullptr);
+    ASSERT_NE(any.data(int_info), nullptr);
+    ASSERT_NE(cany.data(int_info), nullptr);
+    ASSERT_NE(any.as_ref().data(int_info), nullptr);
+    ASSERT_EQ(cany.as_ref().data(int_info), nullptr);
+}
+
 TEST(Any, AnyCast) {
     entt::any any{2};
     const auto &cany = any;
@@ -1552,7 +1617,7 @@ TEST(Any, NonCopyableType) {
 
     ASSERT_EQ(any.policy(), entt::any_policy::embedded);
     ASSERT_EQ(other.policy(), entt::any_policy::cref);
-    ASSERT_EQ(any.type(), other.type());
+    ASSERT_EQ(any.info(), other.info());
 
     ASSERT_FALSE(any.assign(other));
     ASSERT_FALSE(any.assign(std::move(other)));
@@ -1609,7 +1674,7 @@ TEST(Any, NonMovableType) {
 
     ASSERT_EQ(any.policy(), entt::any_policy::dynamic);
     ASSERT_EQ(other.policy(), entt::any_policy::dynamic);
-    ASSERT_EQ(any.type(), other.type());
+    ASSERT_EQ(any.info(), other.info());
 
     ASSERT_TRUE(any.assign(other));
     ASSERT_TRUE(any.assign(std::move(other)));
@@ -1646,17 +1711,17 @@ TEST(Any, Array) {
     ASSERT_FALSE(copy);
 
     // NOLINTBEGIN(*-avoid-c-arrays)
-    ASSERT_EQ(any.type(), entt::type_id<int[1]>());
+    ASSERT_EQ(any.info(), entt::type_id<int[1]>());
     ASSERT_NE(entt::any_cast<int[1]>(&any), nullptr);
     ASSERT_EQ(entt::any_cast<int[2]>(&any), nullptr);
     // NOLINTEND(*-avoid-c-arrays)
     ASSERT_EQ(entt::any_cast<int *>(&any), nullptr);
 
     // NOLINTNEXTLINE(*-avoid-c-arrays)
-    entt::any_cast<int(&)[1]>(any)[0] = 2;
+    entt::any_cast<int (&)[1]>(any)[0] = 2;
 
     // NOLINTNEXTLINE(*-avoid-c-arrays)
-    ASSERT_EQ(entt::any_cast<const int(&)[1]>(std::as_const(any))[0], 2);
+    ASSERT_EQ(entt::any_cast<const int (&)[1]>(std::as_const(any))[0], 2);
 }
 
 TEST(Any, CopyMoveReference) {
@@ -1677,8 +1742,8 @@ TEST(Any, CopyMoveReference) {
     ASSERT_EQ(move.policy(), entt::any_policy::ref);
     ASSERT_EQ(copy.policy(), entt::any_policy::embedded);
 
-    ASSERT_EQ(move.type(), entt::type_id<int>());
-    ASSERT_EQ(copy.type(), entt::type_id<int>());
+    ASSERT_EQ(move.info(), entt::type_id<int>());
+    ASSERT_EQ(copy.info(), entt::type_id<int>());
 
     ASSERT_EQ(std::as_const(move).data(), &value);
     ASSERT_NE(std::as_const(copy).data(), &value);
@@ -1710,8 +1775,8 @@ TEST(Any, CopyMoveConstReference) {
     ASSERT_EQ(move.policy(), entt::any_policy::cref);
     ASSERT_EQ(copy.policy(), entt::any_policy::embedded);
 
-    ASSERT_EQ(move.type(), entt::type_id<int>());
-    ASSERT_EQ(copy.type(), entt::type_id<int>());
+    ASSERT_EQ(move.info(), entt::type_id<int>());
+    ASSERT_EQ(copy.info(), entt::type_id<int>());
 
     ASSERT_EQ(std::as_const(move).data(), &value);
     ASSERT_NE(std::as_const(copy).data(), &value);
@@ -1746,17 +1811,13 @@ TEST(Any, SboAlignment) {
     std::array<any_type, 2u> sbo = {over_aligned{}, over_aligned{}};
     const auto *data = sbo[0].data();
 
-    // NOLINTBEGIN(*-reinterpret-cast)
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(sbo[0u].data()) % alignment) == 0u);
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(sbo[1u].data()) % alignment) == 0u);
-    // NOLINTEND(*-reinterpret-cast)
 
     std::swap(sbo[0], sbo[1]);
 
-    // NOLINTBEGIN(*-reinterpret-cast)
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(sbo[0u].data()) % alignment) == 0u);
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(sbo[1u].data()) % alignment) == 0u);
-    // NOLINTEND(*-reinterpret-cast)
 
     ASSERT_NE(data, sbo[1].data());
 }
@@ -1768,17 +1829,13 @@ TEST(Any, NoSboAlignment) {
     std::array<any_type, 2u> nosbo = {over_aligned{}, over_aligned{}};
     const auto *data = nosbo[0].data();
 
-    // NOLINTBEGIN(*-reinterpret-cast)
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(nosbo[0u].data()) % alignment) == 0u);
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(nosbo[1u].data()) % alignment) == 0u);
-    // NOLINTEND(*-reinterpret-cast)
 
     std::swap(nosbo[0], nosbo[1]);
 
-    // NOLINTBEGIN(*-reinterpret-cast)
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(nosbo[0u].data()) % alignment) == 0u);
     ASSERT_TRUE((reinterpret_cast<std::uintptr_t>(nosbo[1u].data()) % alignment) == 0u);
-    // NOLINTEND(*-reinterpret-cast)
 
     ASSERT_EQ(data, nosbo[1].data());
 }
@@ -1792,13 +1849,13 @@ TEST(Any, DeducedArrayType) {
     entt::any any{"array of char"};
 
     ASSERT_TRUE(any);
-    ASSERT_EQ(any.type(), entt::type_id<const char *>());
+    ASSERT_EQ(any.info(), entt::type_id<const char *>());
     ASSERT_EQ((std::strcmp("array of char", entt::any_cast<const char *>(any))), 0);
 
     any = "another array of char";
 
     ASSERT_TRUE(any);
-    ASSERT_EQ(any.type(), entt::type_id<const char *>());
+    ASSERT_EQ(any.info(), entt::type_id<const char *>());
     ASSERT_EQ((std::strcmp("another array of char", entt::any_cast<const char *>(any))), 0);
 }
 
@@ -1807,6 +1864,6 @@ TEST(Any, ClassLevelNewDelete) {
     entt::any any{std::in_place_type<test::new_delete>, *std::make_unique<test::new_delete>(test::new_delete{3})};
 
     ASSERT_TRUE(any);
-    ASSERT_EQ(any.type(), entt::type_id<test::new_delete>());
+    ASSERT_EQ(any.info(), entt::type_id<test::new_delete>());
     ASSERT_EQ(entt::any_cast<const test::new_delete &>(any).value, 3);
 }
