@@ -3,7 +3,7 @@
 #include <vector>
 #include <gtest/gtest.h>
 #include <entt/core/iterator.hpp>
-#include "../common/boxed_int.h"
+#include "../../common/boxed_type.h"
 
 TEST(InputIteratorPointer, Functionalities) {
     entt::input_iterator_pointer ptr{test::boxed_int{0}};
@@ -46,7 +46,7 @@ TEST(IterableAdaptor, Functionalities) {
     ASSERT_EQ(*++iterable.cbegin(), 2);
     ASSERT_EQ(++iterable.cbegin(), --iterable.end());
 
-    for(auto value: entt::iterable_adaptor<const int *, const void *>{&vec[0u], &vec[1u]}) {
+    for(auto value: entt::iterable_adaptor<const int *, const void *>{vec.data(), &vec[1u]}) {
         ASSERT_EQ(value, 1);
     }
 }
