@@ -309,13 +309,15 @@ TEST(Registry, Swap) {
     other.erase<int>(entity);
 
     registry = {};
-    registry.emplace<int>(registry.create(entity));
+    const auto reboot = registry.create();
+    registry.emplace<int>(reboot);
 
+    ASSERT_EQ(entity, reboot);
     ASSERT_EQ(test.parent, &other);
 
     registry.swap(other);
-    registry.emplace<int>(entity);
-    registry.emplace<int>(registry.create(entity));
+    registry.emplace<int>(reboot);
+    registry.emplace<int>(registry.create(reboot));
 
     ASSERT_EQ(test.parent, &registry);
 }
@@ -466,9 +468,9 @@ TEST(Registry, RegistryStorageIteratorConversion) {
     testing::StaticAssertTypeEq<decltype(*cit), std::pair<entt::id_type, const entt::sparse_set &>>();
 
     ASSERT_EQ(it->first, entt::type_id<int>().hash());
-    ASSERT_EQ((*it).second.type(), entt::type_id<int>());
+    ASSERT_EQ((*it).second.info(), entt::type_id<int>());
     ASSERT_EQ(it->first, cit->first);
-    ASSERT_EQ((*it).second.type(), (*cit).second.type());
+    ASSERT_EQ((*it).second.info(), (*cit).second.info());
 
     ASSERT_EQ(it - cit, 0);
     ASSERT_EQ(cit - it, 0);
@@ -973,7 +975,7 @@ TEST(Registry, EmplaceEmpty) {
 
     ASSERT_FALSE(registry.all_of<test::empty>(entity));
 
-    registry.emplace<test::empty>(entity, 4);
+    registry.emplace<test::empty>(entity);
 
     ASSERT_TRUE(registry.all_of<test::empty>(entity));
 }
@@ -1442,7 +1444,7 @@ TEST(Registry, EraseIf) {
     ASSERT_FALSE(registry.storage<int>("other"_hs).contains(entity));
     ASSERT_TRUE(registry.storage<char>().contains(entity));
 
-    registry.erase_if(entity, [](auto, const auto &storage) { return storage.type() == entt::type_id<char>(); });
+    registry.erase_if(entity, [](auto, const auto &storage) { return storage.info() == entt::type_id<char>(); });
 
     ASSERT_TRUE(registry.storage<int>().contains(entity));
     ASSERT_FALSE(registry.storage<int>("other"_hs).contains(entity));
@@ -2353,6 +2355,14 @@ TEST(Registry, Context) {
     ASSERT_EQ(ctx.find<const int>(), cctx.find<int>());
     ASSERT_EQ(ctx.get<int>(), cctx.get<const int>());
     ASSERT_EQ(ctx.get<int>(), 0);
+
+    ASSERT_TRUE(ctx.contains<char>());
+    ASSERT_TRUE(ctx.contains<int>());
+
+    ctx.clear();
+
+    ASSERT_FALSE(ctx.contains<char>());
+    ASSERT_FALSE(ctx.contains<int>());
 }
 
 TEST(Registry, ContextHint) {
@@ -2546,8 +2556,8 @@ TEST(Registry, VoidType) {
     ASSERT_FALSE(registry.storage<void>("custom"_hs).empty());
     ASSERT_TRUE(registry.storage<void>("custom"_hs).contains(entity));
 
-    ASSERT_EQ(registry.storage<void>().type(), entt::type_id<void>());
-    ASSERT_EQ(registry.storage<void>("custom"_hs).type(), entt::type_id<void>());
+    ASSERT_EQ(registry.storage<void>().info(), entt::type_id<void>());
+    ASSERT_EQ(registry.storage<void>("custom"_hs).info(), entt::type_id<void>());
 }
 
 TEST(Registry, NoEtoType) {
