@@ -22,21 +22,12 @@ struct StorageNoInstance: testing::Test {
     using type = Type;
 
     static auto emplace_instance(entt::storage<type> &pool, const entt::entity entt) {
-        if constexpr(std::is_void_v<type>) {
-            return pool.emplace(entt);
-        } else {
-            return pool.emplace(entt, type{});
-        }
+        return pool.emplace(entt);
     }
 
     template<typename It>
     static auto insert_instance(entt::storage<type> &pool, const It from, const It to) {
-        if constexpr(std::is_void_v<type>) {
-            return pool.insert(from, to);
-        } else {
-            const std::array<type, 2u> value{};
-            return pool.insert(from, to, value.begin());
-        }
+        return pool.insert(from, to);
     }
 
     static auto push_instance(entt::storage<type> &pool, const entt::entity entt) {
@@ -64,13 +55,13 @@ TYPED_TEST(StorageNoInstance, Constructors) {
 
     ASSERT_EQ(pool.policy(), entt::deletion_policy::swap_and_pop);
     ASSERT_NO_THROW([[maybe_unused]] auto alloc = pool.get_allocator());
-    ASSERT_EQ(pool.type(), entt::type_id<value_type>());
+    ASSERT_EQ(pool.info(), entt::type_id<value_type>());
 
     pool = entt::storage<value_type>{std::allocator<value_type>{}};
 
     ASSERT_EQ(pool.policy(), entt::deletion_policy::swap_and_pop);
     ASSERT_NO_THROW([[maybe_unused]] auto alloc = pool.get_allocator());
-    ASSERT_EQ(pool.type(), entt::type_id<value_type>());
+    ASSERT_EQ(pool.info(), entt::type_id<value_type>());
 }
 
 TYPED_TEST(StorageNoInstance, Move) {
@@ -91,7 +82,7 @@ TYPED_TEST(StorageNoInstance, Move) {
     ASSERT_TRUE(pool.empty());
     ASSERT_FALSE(other.empty());
 
-    ASSERT_EQ(other.type(), entt::type_id<value_type>());
+    ASSERT_EQ(other.info(), entt::type_id<value_type>());
     ASSERT_EQ(other.index(entity[0u]), 0u);
 
     entt::storage<value_type> extended{std::move(other), std::allocator<value_type>{}};
@@ -101,7 +92,7 @@ TYPED_TEST(StorageNoInstance, Move) {
     ASSERT_TRUE(other.empty());
     ASSERT_FALSE(extended.empty());
 
-    ASSERT_EQ(extended.type(), entt::type_id<value_type>());
+    ASSERT_EQ(extended.info(), entt::type_id<value_type>());
     ASSERT_EQ(extended.index(entity[0u]), 0u);
 
     pool = std::move(extended);
@@ -111,18 +102,18 @@ TYPED_TEST(StorageNoInstance, Move) {
     ASSERT_TRUE(other.empty());
     ASSERT_TRUE(extended.empty());
 
-    ASSERT_EQ(pool.type(), entt::type_id<value_type>());
+    ASSERT_EQ(pool.info(), entt::type_id<value_type>());
     ASSERT_EQ(pool.index(entity[0u]), 0u);
 
     other = entt::storage<value_type>{};
-    other.emplace(entity[1u], 2);
+    other.emplace(entity[1u]);
     other = std::move(pool);
     test::is_initialized(pool);
 
     ASSERT_FALSE(pool.empty());
     ASSERT_FALSE(other.empty());
 
-    ASSERT_EQ(other.type(), entt::type_id<value_type>());
+    ASSERT_EQ(other.info(), entt::type_id<value_type>());
     ASSERT_EQ(other.index(entity[0u]), 0u);
 }
 
@@ -132,8 +123,8 @@ TYPED_TEST(StorageNoInstance, Swap) {
     entt::storage<value_type> pool;
     entt::storage<value_type> other;
 
-    ASSERT_EQ(pool.type(), entt::type_id<value_type>());
-    ASSERT_EQ(other.type(), entt::type_id<value_type>());
+    ASSERT_EQ(pool.info(), entt::type_id<value_type>());
+    ASSERT_EQ(other.info(), entt::type_id<value_type>());
 
     pool.emplace(entt::entity{4});
 
@@ -146,8 +137,8 @@ TYPED_TEST(StorageNoInstance, Swap) {
 
     pool.swap(other);
 
-    ASSERT_EQ(pool.type(), entt::type_id<value_type>());
-    ASSERT_EQ(other.type(), entt::type_id<value_type>());
+    ASSERT_EQ(pool.info(), entt::type_id<value_type>());
+    ASSERT_EQ(other.info(), entt::type_id<value_type>());
 
     ASSERT_EQ(pool.size(), 1u);
     ASSERT_EQ(other.size(), 1u);
@@ -162,7 +153,7 @@ TYPED_TEST(StorageNoInstance, Getters) {
     entt::storage<value_type> pool;
     const entt::entity entity{4};
 
-    pool.emplace(entity, 3);
+    pool.emplace(entity);
 
     testing::StaticAssertTypeEq<decltype(pool.get({})), void>();
     testing::StaticAssertTypeEq<decltype(std::as_const(pool).get({})), void>();
