@@ -5,7 +5,10 @@
 #include <memory>
 #include <utility>
 #include <gtest/gtest.h>
+#include <entt/core/any.hpp>
 #include <entt/core/hashed_string.hpp>
+#include <entt/locator/locator.hpp>
+#include <entt/meta/context.hpp>
 #include <entt/meta/factory.hpp>
 #include <entt/meta/meta.hpp>
 #include <entt/meta/resolve.hpp>
@@ -36,15 +39,10 @@ struct empty {
     empty &operator=(const empty &) = default;
 
     virtual ~empty() {
-        ++destructor_counter;
+        ++counter;
     }
 
-    static void destroy(empty &) {
-        ++destroy_counter;
-    }
-
-    inline static int destroy_counter = 0;    // NOLINT
-    inline static int destructor_counter = 0; // NOLINT
+    inline static int counter = 0; // NOLINT
 };
 
 struct fat: empty {
@@ -91,13 +89,11 @@ struct MetaAny: ::testing::Test {
         using namespace entt::literals;
 
         entt::meta_factory<empty>{}
-            .type("empty"_hs)
-            .dtor<empty::destroy>();
+            .type("empty"_hs);
 
         entt::meta_factory<fat>{}
             .type("fat"_hs)
-            .base<empty>()
-            .dtor<fat::destroy>();
+            .base<empty>();
 
         entt::meta_factory<clazz>{}
             .type("clazz"_hs)
@@ -106,8 +102,7 @@ struct MetaAny: ::testing::Test {
             .func<clazz::func>("func"_hs)
             .conv<int>();
 
-        empty::destroy_counter = 0;
-        empty::destructor_counter = 0;
+        empty::counter = 0;
     }
 
     void TearDown() override {
@@ -154,10 +149,10 @@ TEST_F(MetaAny, SBO) {
 
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.base().owner());
-    ASSERT_EQ(any.policy(), entt::meta_any_policy::embedded);
+    ASSERT_EQ(any.base().policy(), entt::any_policy::embedded);
     ASSERT_FALSE(any.try_cast<std::size_t>());
     ASSERT_EQ(any.cast<char>(), 'c');
-    ASSERT_NE(any.data(), nullptr);
+    ASSERT_NE(any.base().data(), nullptr);
     ASSERT_EQ(any, entt::meta_any{'c'});
     ASSERT_NE(entt::meta_any{'h'}, any);
 }
@@ -168,10 +163,10 @@ TEST_F(MetaAny, NoSBO) {
 
     ASSERT_TRUE(any);
     ASSERT_TRUE(any.base().owner());
-    ASSERT_EQ(any.policy(), entt::meta_any_policy::dynamic);
+    ASSERT_EQ(any.base().policy(), entt::any_policy::dynamic);
     ASSERT_FALSE(any.try_cast<std::size_t>());
     ASSERT_EQ(any.cast<fat>(), instance);
-    ASSERT_NE(any.data(), nullptr);
+    ASSERT_NE(any.base().data(), nullptr);
     ASSERT_EQ(any, entt::meta_any{instance});
     ASSERT_NE(any, fat{});
 }
@@ -194,7 +189,7 @@ TEST_F(MetaAny, SBOInPlaceConstruction) {
 
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.base().owner());
-    ASSERT_EQ(other.policy(), entt::any_policy::ref);
+    ASSERT_EQ(other.base().policy(), entt::any_policy::ref);
     ASSERT_FALSE(other.try_cast<std::size_t>());
     ASSERT_EQ(other.cast<int>(), 2);
     ASSERT_NE(other.base().data(), nullptr);
@@ -371,15 +366,17 @@ TEST_F(MetaAny, SBOMoveAssignment) {
     ASSERT_NE(other, entt::meta_any{0});
 }
 
-TEST_F(MetaAnyDeathTest, SBOSelfMoveAssignment) {
+TEST_F(MetaAny, SBOSelfMoveAssignment) {
     entt::meta_any any{3};
 
     // avoid warnings due to self-assignment
     any = std::move(*&any);
 
-    ASSERT_FALSE(any);
-    ASSERT_FALSE(any.type());
-    ASSERT_EQ(any.base().data(), nullptr);
+    ASSERT_TRUE(any);
+    ASSERT_FALSE(any.try_cast<std::size_t>());
+    ASSERT_EQ(any.cast<int>(), 3);
+    ASSERT_EQ(any, entt::meta_any{3});
+    ASSERT_NE(any, entt::meta_any{0});
 }
 
 TEST_F(MetaAny, SBODirectAssignment) {
@@ -526,7 +523,7 @@ TEST_F(MetaAny, NoSBOInPlaceConstruction) {
 
     ASSERT_TRUE(other);
     ASSERT_FALSE(other.base().owner());
-    ASSERT_EQ(other.policy(), entt::any_policy::ref);
+    ASSERT_EQ(other.base().policy(), entt::any_policy::ref);
     ASSERT_FALSE(other.try_cast<std::size_t>());
     ASSERT_EQ(other.cast<fat>(), instance);
     ASSERT_NE(other.base().data(), nullptr);
@@ -705,16 +702,18 @@ TEST_F(MetaAny, NoSBOMoveAssignment) {
     ASSERT_NE(other, fat{});
 }
 
-TEST_F(MetaAnyDeathTest, NoSBOSelfMoveAssignment) {
+TEST_F(MetaAny, NoSBOSelfMoveAssignment) {
     const fat instance{.1, .2, .3, .4};
     entt::meta_any any{instance};
 
     // avoid warnings due to self-assignment
     any = std::move(*&any);
 
-    ASSERT_FALSE(any);
-    ASSERT_FALSE(any.type());
-    ASSERT_EQ(any.base().data(), nullptr);
+    ASSERT_TRUE(any);
+    ASSERT_FALSE(any.try_cast<std::size_t>());
+    ASSERT_EQ(any.cast<fat>(), instance);
+    ASSERT_EQ(any, entt::meta_any{instance});
+    ASSERT_NE(any, fat{});
 }
 
 TEST_F(MetaAny, NoSBODirectAssignment) {
@@ -961,15 +960,16 @@ TEST_F(MetaAny, VoidMoveAssignment) {
     ASSERT_EQ(other, entt::meta_any{std::in_place_type<void>});
 }
 
-TEST_F(MetaAnyDeathTest, VoidSelfMoveAssignment) {
+TEST_F(MetaAny, VoidSelfMoveAssignment) {
     entt::meta_any any{std::in_place_type<void>};
 
     // avoid warnings due to self-assignment
     any = std::move(*&any);
 
-    ASSERT_FALSE(any);
-    ASSERT_FALSE(any.type());
-    ASSERT_EQ(any.base().data(), nullptr);
+    ASSERT_TRUE(any);
+    ASSERT_FALSE(any.try_cast<std::size_t>());
+    ASSERT_EQ(any.type(), entt::resolve<void>());
+    ASSERT_EQ(any, entt::meta_any{std::in_place_type<void>});
 }
 
 TEST_F(MetaAny, SBOMoveInvalidate) {
@@ -1021,8 +1021,7 @@ TEST_F(MetaAny, SBODestruction) {
         any = std::move(other);
     }
 
-    ASSERT_EQ(empty::destroy_counter, 3);
-    ASSERT_EQ(empty::destructor_counter, 6);
+    ASSERT_EQ(empty::counter, 6);
 }
 
 TEST_F(MetaAny, NoSBODestruction) {
@@ -1034,8 +1033,7 @@ TEST_F(MetaAny, NoSBODestruction) {
         any = std::move(other);
     }
 
-    ASSERT_EQ(fat::destroy_counter, 3);
-    ASSERT_EQ(empty::destructor_counter, 4);
+    ASSERT_EQ(empty::counter, 4);
 }
 
 TEST_F(MetaAny, VoidDestruction) {
@@ -1328,16 +1326,21 @@ TEST_F(MetaAny, Cast) {
 }
 
 TEST_F(MetaAny, AllowCast) {
+    entt::meta_any any{};
     entt::meta_any instance{clazz{}};
     entt::meta_any other{fat{}};
     entt::meta_any arithmetic{3};
     auto as_cref = entt::forward_as_meta(arithmetic.cast<const int &>());
 
+    ASSERT_FALSE(any);
     ASSERT_TRUE(instance);
     ASSERT_TRUE(other);
     ASSERT_TRUE(arithmetic);
     ASSERT_TRUE(as_cref);
 
+    ASSERT_FALSE(any.allow_cast<clazz>());
+    ASSERT_FALSE(std::as_const(any).allow_cast<clazz>());
+
     ASSERT_TRUE(instance.allow_cast<clazz>());
     ASSERT_TRUE(instance.allow_cast<clazz &>());
     ASSERT_TRUE(instance.allow_cast<const clazz &>());
@@ -1386,16 +1389,20 @@ TEST_F(MetaAny, AllowCast) {
 }
 
 TEST_F(MetaAny, OpaqueAllowCast) {
+    entt::meta_any any{};
     entt::meta_any instance{clazz{}};
     entt::meta_any other{fat{}};
     entt::meta_any arithmetic{3};
     auto as_cref = entt::forward_as_meta(arithmetic.cast<const int &>());
 
+    ASSERT_FALSE(any);
     ASSERT_TRUE(instance);
     ASSERT_TRUE(other);
     ASSERT_TRUE(arithmetic);
     ASSERT_TRUE(as_cref);
 
+    ASSERT_FALSE(any.allow_cast(entt::resolve<clazz>()));
+
     ASSERT_TRUE(instance.allow_cast(entt::resolve<clazz>()));
     ASSERT_EQ(instance.type(), entt::resolve<clazz>());
 
