@@ -17,18 +17,10 @@
 
 struct base {
     virtual ~base() = default;
-
-    static void destroy(base &) {
-        ++counter;
-    }
-
-    inline static int counter = 0; // NOLINT
     int value{3};
 };
 
-struct derived: base {
-    derived() = default;
-};
+struct derived: base {};
 
 struct clazz {
     operator int() const {
@@ -70,18 +62,6 @@ struct setter_getter {
     int value{0};
 };
 
-struct multi_setter {
-    void from_double(double val) {
-        value = static_cast<int>(val);
-    }
-
-    void from_string(const char *val) {
-        value = std::atoi(val);
-    }
-
-    int value{0};
-};
-
 struct array {
     inline static int global[2]; // NOLINT
     int local[4];                // NOLINT
@@ -93,13 +73,11 @@ struct MetaData: ::testing::Test {
 
         entt::meta_factory<base>{}
             .type("base"_hs)
-            .dtor<base::destroy>()
             .data<&base::value>("value"_hs);
 
         entt::meta_factory<derived>{}
             .type("derived"_hs)
             .base<base>()
-            .dtor<derived::destroy>()
             .data<&base::value>("value_from_base"_hs);
 
         entt::meta_factory<clazz>{}
@@ -108,9 +86,9 @@ struct MetaData: ::testing::Test {
             .custom<char>('c')
             .traits(test::meta_traits::one | test::meta_traits::two | test::meta_traits::three)
             .data<&clazz::i, entt::as_cref_t>("ci"_hs)
-            .data<&clazz::j>("j"_hs)
+            .data<&clazz::j>("j")
             .traits(test::meta_traits::one)
-            .data<&clazz::h>("h"_hs)
+            .data<&clazz::h>("h"_hs, "hhh")
             .traits(test::meta_traits::two)
             .data<&clazz::k>("k"_hs)
             .traits(test::meta_traits::three)
@@ -119,25 +97,26 @@ struct MetaData: ::testing::Test {
             .data<&clazz::i, entt::as_void_t>("void"_hs)
             .conv<int>();
 
+        entt::meta_factory<clazz>{}
+            .data<&clazz::i, entt::as_is_t>("ir"_hs)
+            .data<&clazz::j, entt::as_is_t>("jc"_hs)
+            .data<&clazz::h, entt::as_is_t>("hr"_hs)
+            .data<&clazz::k, entt::as_is_t>("kc"_hs)
+            .data<nullptr, &clazz::operator int, entt::as_is_t>("ov"_hs);
+
         entt::meta_factory<setter_getter>{}
             .type("setter_getter"_hs)
             .data<&setter_getter::static_setter, &setter_getter::static_getter>("x"_hs)
             .data<&setter_getter::setter, &setter_getter::getter>("y"_hs)
             .data<&setter_getter::static_setter, &setter_getter::getter>("z"_hs)
-            .data<&setter_getter::setter_with_ref, &setter_getter::getter_with_ref>("w"_hs)
-            .data<nullptr, &setter_getter::getter>("z_ro"_hs)
+            .data<&setter_getter::setter_with_ref, &setter_getter::getter_with_ref>("w")
+            .data<nullptr, &setter_getter::getter>("z_ro"_hs, "readonly")
             .data<nullptr, &setter_getter::value>("value"_hs);
 
-        entt::meta_factory<multi_setter>{}
-            .type("multi_setter"_hs)
-            .data<entt::value_list<&multi_setter::from_double, &multi_setter::from_string>, &multi_setter::value>("value"_hs);
-
         entt::meta_factory<array>{}
             .type("array"_hs)
             .data<&array::global>("global"_hs)
             .data<&array::local>("local"_hs);
-
-        base::counter = 0;
     }
 
     void TearDown() override {
@@ -147,22 +126,6 @@ struct MetaData: ::testing::Test {
 
 using MetaDataDeathTest = MetaData;
 
-TEST_F(MetaData, SafeWhenEmpty) {
-    const entt::meta_data data{};
-
-    ASSERT_FALSE(data);
-    ASSERT_EQ(data, entt::meta_data{});
-    ASSERT_EQ(data.arity(), 0u);
-    ASSERT_FALSE(data.is_const());
-    ASSERT_FALSE(data.is_static());
-    ASSERT_EQ(data.type(), entt::meta_type{});
-    ASSERT_FALSE(data.set({}, 0));
-    ASSERT_FALSE(data.get({}));
-    ASSERT_EQ(data.arg(0u), entt::meta_type{});
-    ASSERT_EQ(data.traits<test::meta_traits>(), test::meta_traits::none);
-    ASSERT_EQ(static_cast<const char *>(data.custom()), nullptr);
-}
-
 TEST_F(MetaData, UserTraits) {
     using namespace entt::literals;
 
@@ -200,6 +163,21 @@ ENTT_DEBUG_TEST_F(MetaDataDeathTest, Custom) {
     ASSERT_DEATH([[maybe_unused]] const char value = entt::resolve<clazz>().data("j"_hs).custom(), "");
 }
 
+TEST_F(MetaData, Name) {
+    using namespace entt::literals;
+
+    const entt::meta_type type = entt::resolve<clazz>();
+    const entt::meta_type other = entt::resolve<setter_getter>();
+
+    ASSERT_EQ(type.data("i"_hs).name(), nullptr);
+    ASSERT_STREQ(type.data("j"_hs).name(), "j");
+    ASSERT_STREQ(type.data("h"_hs).name(), "hhh");
+
+    ASSERT_EQ(other.data("z"_hs).name(), nullptr);
+    ASSERT_STREQ(other.data("w"_hs).name(), "w");
+    ASSERT_STREQ(other.data("z_ro"_hs).name(), "readonly");
+}
+
 TEST_F(MetaData, Comparison) {
     using namespace entt::literals;
 
@@ -335,10 +313,13 @@ TEST_F(MetaData, SetCast) {
     using namespace entt::literals;
 
     clazz instance{};
+    derived other{};
 
-    ASSERT_EQ(base::counter, 0);
-    ASSERT_TRUE(entt::resolve<clazz>().data("base"_hs).set(instance, derived{}));
-    ASSERT_EQ(base::counter, 1);
+    other.value = 1;
+
+    ASSERT_EQ(instance.instance.value, 3);
+    ASSERT_TRUE(entt::resolve<clazz>().data("base"_hs).set(instance, other));
+    ASSERT_EQ(instance.instance.value, 1);
 }
 
 TEST_F(MetaData, SetConvert) {
@@ -490,30 +471,6 @@ TEST_F(MetaData, SetterGetterReadOnlyDataMember) {
     ASSERT_EQ(data.get(instance).cast<int>(), 0);
 }
 
-TEST_F(MetaData, MultiSetter) {
-    using namespace entt::literals;
-
-    auto data = entt::resolve<multi_setter>().data("value"_hs);
-    multi_setter instance{};
-
-    ASSERT_TRUE(data);
-    ASSERT_EQ(data.arity(), 2u);
-    ASSERT_EQ(data.type(), entt::resolve<int>());
-    ASSERT_EQ(data.arg(0u), entt::resolve<double>());
-    ASSERT_EQ(data.arg(1u), entt::resolve<const char *>());
-    ASSERT_EQ(data.arg(2u), entt::meta_type{});
-    ASSERT_FALSE(data.is_const());
-    ASSERT_FALSE(data.is_static());
-    ASSERT_EQ(data.get(instance).cast<int>(), 0);
-    ASSERT_TRUE(data.set(instance, 1));
-    ASSERT_EQ(data.get(instance).cast<int>(), 1);
-    ASSERT_TRUE(data.set(instance, 2.));
-    ASSERT_EQ(data.get(instance).cast<int>(), 2);
-    ASSERT_FALSE(data.set(instance, std::string{"3"}));
-    ASSERT_TRUE(data.set(instance, std::string{"3"}.c_str()));
-    ASSERT_EQ(data.get(instance).cast<int>(), 3);
-}
-
 TEST_F(MetaData, ConstInstance) {
     using namespace entt::literals;
 
@@ -591,6 +548,44 @@ TEST_F(MetaData, AsVoid) {
     ASSERT_EQ(data.get(instance), entt::meta_any{std::in_place_type<void>});
 }
 
+TEST_F(MetaData, AsIs) {
+    using namespace entt::literals;
+
+    auto type = entt::resolve<clazz>();
+    entt::meta_data data{};
+    clazz instance{};
+
+    data = type.data("ir"_hs);
+
+    ASSERT_TRUE(data);
+    ASSERT_EQ(data.type(), entt::resolve<int>());
+    ASSERT_EQ(data.get(instance).base().policy(), entt::any_policy::ref);
+
+    data = type.data("jc"_hs);
+
+    ASSERT_TRUE(data);
+    ASSERT_EQ(data.type(), entt::resolve<int>());
+    ASSERT_EQ(data.get(instance).base().policy(), entt::any_policy::cref);
+
+    data = type.data("hr"_hs);
+
+    ASSERT_TRUE(data);
+    ASSERT_EQ(data.type(), entt::resolve<int>());
+    ASSERT_EQ(data.get(instance).base().policy(), entt::any_policy::ref);
+
+    data = type.data("kc"_hs);
+
+    ASSERT_TRUE(data);
+    ASSERT_EQ(data.type(), entt::resolve<int>());
+    ASSERT_EQ(data.get(instance).base().policy(), entt::any_policy::cref);
+
+    data = type.data("ov"_hs);
+
+    ASSERT_TRUE(data);
+    ASSERT_EQ(data.type(), entt::resolve<int>());
+    ASSERT_EQ(data.get(instance).base().policy(), entt::any_policy::embedded);
+}
+
 TEST_F(MetaData, AsRef) {
     using namespace entt::literals;
 
