@@ -58,6 +58,10 @@ struct function {
         return value * iv;
     }
 
+    [[nodiscard]] int f(int iv) {
+        return (value += iv);
+    }
+
     void g(int iv) {
         value = iv * iv;
     }
@@ -70,7 +74,7 @@ struct function {
         instance.value = iv;
     }
 
-    [[nodiscard]] int v(int &iv) const {
+    [[nodiscard]] const int &v(int &iv) const {
         return (iv = value);
     }
 
@@ -107,8 +111,8 @@ struct MetaFunc: ::testing::Test {
             .type("derived"_hs)
             .base<base>()
             .func<&base::setter>("setter_from_base"_hs)
-            .func<&base::getter>("getter_from_base"_hs)
-            .func<&base::static_setter>("static_setter_from_base"_hs);
+            .func<&base::getter>("getter_from_base")
+            .func<&base::static_setter>("static_setter_from_base"_hs, "static setter");
 
         entt::meta_factory<function>{}
             .type("func"_hs)
@@ -121,6 +125,10 @@ struct MetaFunc: ::testing::Test {
             .custom<int>(2)
             .func<entt::overload<int(int) const>(&function::f)>("f1"_hs)
             .traits(test::meta_traits::one)
+            .func<entt::overload<int(int) const>(&function::f)>("cf"_hs)
+            .func<entt::overload<int(int)>(&function::f)>("cf"_hs)
+            .func<entt::overload<int(int)>(&function::f)>("ncf"_hs)
+            .func<entt::overload<int(int) const>(&function::f)>("ncf"_hs)
             .func<&function::g>("g"_hs)
             .custom<char>('c')
             .func<function::h>("h"_hs)
@@ -129,6 +137,12 @@ struct MetaFunc: ::testing::Test {
             .func<&function::a, entt::as_ref_t>("a"_hs)
             .func<&function::a, entt::as_cref_t>("ca"_hs)
             .conv<int>();
+
+        entt::meta_factory<function>{}
+            .func<&function::a, entt::as_is_t>("ar"_hs)
+            .func<&function::v, entt::as_is_t>("vc"_hs)
+            .func<&function::operator int, entt::as_is_t>("ov"_hs)
+            .func<&function::g, entt::as_is_t>("ge"_hs);
     }
 
     void TearDown() override {
@@ -158,27 +172,6 @@ struct MetaFunc: ::testing::Test {
 
 using MetaFuncDeathTest = MetaFunc;
 
-TEST_F(MetaFunc, SafeWhenEmpty) {
-    const entt::meta_func func{};
-    entt::meta_any *args = nullptr;
-
-    ASSERT_FALSE(func);
-    ASSERT_EQ(func, entt::meta_func{});
-    ASSERT_EQ(func.arity(), 0u);
-    ASSERT_FALSE(func.is_const());
-    ASSERT_FALSE(func.is_static());
-    ASSERT_EQ(func.ret(), entt::meta_type{});
-    ASSERT_EQ(func.arg(0u), entt::meta_type{});
-    ASSERT_EQ(func.arg(1u), entt::meta_type{});
-    ASSERT_FALSE(func.invoke({}, args, 0u));
-    ASSERT_FALSE(func.invoke({}, args, 1u));
-    ASSERT_FALSE(func.invoke({}));
-    ASSERT_FALSE(func.invoke({}, 'c'));
-    ASSERT_EQ(func.traits<test::meta_traits>(), test::meta_traits::none);
-    ASSERT_EQ(static_cast<const char *>(func.custom()), nullptr);
-    ASSERT_EQ(func.next(), func);
-}
-
 TEST_F(MetaFunc, UserTraits) {
     using namespace entt::literals;
 
@@ -216,6 +209,16 @@ ENTT_DEBUG_TEST_F(MetaFuncDeathTest, Custom) {
     ASSERT_DEATH([[maybe_unused]] const char value = entt::resolve<function>().func("h"_hs).custom(), "");
 }
 
+TEST_F(MetaFunc, Name) {
+    using namespace entt::literals;
+
+    const entt::meta_type type = entt::resolve<derived>();
+
+    ASSERT_EQ(type.func("setter_from_base"_hs).name(), nullptr);
+    ASSERT_STREQ(type.func("getter_from_base"_hs).name(), "getter_from_base");
+    ASSERT_STREQ(type.func("static_setter_from_base"_hs).name(), "static setter");
+}
+
 TEST_F(MetaFunc, Comparison) {
     using namespace entt::literals;
 
@@ -506,6 +509,38 @@ TEST_F(MetaFunc, AsVoid) {
     ASSERT_EQ(value, instance.value);
 }
 
+TEST_F(MetaFunc, AsIs) {
+    using namespace entt::literals;
+
+    auto type = entt::resolve<function>();
+    entt::meta_func func{};
+    function instance{3};
+
+    func = type.func("ar"_hs);
+
+    ASSERT_TRUE(func);
+    ASSERT_EQ(func.ret(), entt::resolve<int>());
+    ASSERT_EQ(func.invoke(instance).base().policy(), entt::any_policy::ref);
+
+    func = type.func("vc"_hs);
+
+    ASSERT_TRUE(func);
+    ASSERT_EQ(func.ret(), entt::resolve<int>());
+    ASSERT_EQ(func.invoke(instance, 3).base().policy(), entt::any_policy::cref);
+
+    func = type.func("ov"_hs);
+
+    ASSERT_TRUE(func);
+    ASSERT_EQ(func.ret(), entt::resolve<int>());
+    ASSERT_EQ(func.invoke(instance).base().policy(), entt::any_policy::embedded);
+
+    func = type.func("ge"_hs);
+
+    ASSERT_TRUE(func);
+    ASSERT_EQ(func.ret(), entt::resolve<void>());
+    ASSERT_EQ(func.invoke(instance).base().policy(), entt::any_policy::empty);
+}
+
 TEST_F(MetaFunc, AsRef) {
     using namespace entt::literals;
 
@@ -633,6 +668,70 @@ TEST_F(MetaFunc, Overloaded) {
     ASSERT_EQ(static_cast<const int &>(type.func("f2"_hs).next().custom()), 3);
 }
 
+TEST_F(MetaFunc, OverloadedConstFirst) {
+    using namespace entt::literals;
+
+    auto func = entt::resolve<function>().func("cf"_hs);
+    auto next = func.next();
+    function instance{2};
+
+    ASSERT_TRUE(func);
+    ASSERT_EQ(func.arity(), 1u);
+    ASSERT_TRUE(func.is_const());
+    ASSERT_EQ(func.ret(), entt::resolve<int>());
+    ASSERT_EQ(func.arg(0u), entt::resolve<int>());
+
+    ASSERT_TRUE(next);
+    ASSERT_EQ(next.arity(), 1u);
+    ASSERT_FALSE(next.is_const());
+    ASSERT_EQ(next.ret(), entt::resolve<int>());
+    ASSERT_EQ(next.arg(0u), entt::resolve<int>());
+
+    ASSERT_EQ(func.invoke(instance, 1).cast<int>(), 2);
+    ASSERT_EQ(next.invoke(instance, 1).cast<int>(), 3);
+
+    ASSERT_EQ(func.invoke(std::as_const(instance), 1).cast<int>(), 3);
+    ASSERT_FALSE(next.invoke(std::as_const(instance), 1));
+
+    ASSERT_EQ(func.invoke(entt::meta_handle{instance}, entt::meta_any{1}).cast<int>(), 3);
+    ASSERT_EQ(next.invoke(entt::meta_handle{instance}, entt::meta_any{1}).cast<int>(), 4);
+
+    ASSERT_EQ(func.invoke(entt::meta_handle{std::as_const(instance)}, entt::meta_any{1}).cast<int>(), 4);
+    ASSERT_FALSE(next.invoke(entt::meta_handle{std::as_const(instance)}, entt::meta_any{1}));
+}
+
+TEST_F(MetaFunc, OverloadedNonConstFirst) {
+    using namespace entt::literals;
+
+    auto func = entt::resolve<function>().func("ncf"_hs);
+    auto next = func.next();
+    function instance{2};
+
+    ASSERT_TRUE(func);
+    ASSERT_EQ(func.arity(), 1u);
+    ASSERT_FALSE(func.is_const());
+    ASSERT_EQ(func.ret(), entt::resolve<int>());
+    ASSERT_EQ(func.arg(0u), entt::resolve<int>());
+
+    ASSERT_TRUE(next);
+    ASSERT_EQ(next.arity(), 1u);
+    ASSERT_TRUE(next.is_const());
+    ASSERT_EQ(next.ret(), entt::resolve<int>());
+    ASSERT_EQ(next.arg(0u), entt::resolve<int>());
+
+    ASSERT_EQ(func.invoke(instance, 1).cast<int>(), 3);
+    ASSERT_EQ(next.invoke(instance, 1).cast<int>(), 3);
+
+    ASSERT_FALSE(func.invoke(std::as_const(instance), 1));
+    ASSERT_EQ(next.invoke(std::as_const(instance), 1).cast<int>(), 3);
+
+    ASSERT_EQ(func.invoke(entt::meta_handle{instance}, entt::meta_any{1}).cast<int>(), 4);
+    ASSERT_EQ(next.invoke(entt::meta_handle{instance}, entt::meta_any{1}).cast<int>(), 4);
+
+    ASSERT_FALSE(func.invoke(entt::meta_handle{std::as_const(instance)}, entt::meta_any{1}));
+    ASSERT_EQ(next.invoke(entt::meta_handle{std::as_const(instance)}, entt::meta_any{1}).cast<int>(), 4);
+}
+
 TEST_F(MetaFunc, OverloadedOrder) {
     using namespace entt::literals;
 
