@@ -32,6 +32,10 @@ Type get(Type &elem) {
 
 struct base {
     char value{'c'};
+
+    static int f() {
+        return 0;
+    }
 };
 
 struct derived: base {
@@ -127,17 +131,18 @@ struct MetaType: ::testing::Test {
             .data<set<double>, get<double>>("var"_hs);
 
         entt::meta_factory<unsigned int>{}
-            .type("unsigned int"_hs)
+            .type("unsigned int"_hs, "uint")
             .traits(test::meta_traits::two)
             .data<0u>("min"_hs)
             .data<128u>("max"_hs);
 
         entt::meta_factory<base>{}
             .type("base"_hs)
-            .data<&base::value>("value"_hs);
+            .data<&base::value>("value"_hs)
+            .func<&base::f>("func"_hs);
 
         entt::meta_factory<derived>{}
-            .type("derived"_hs)
+            .type("derived")
             .traits(test::meta_traits::one | test::meta_traits::three)
             .base<base>();
 
@@ -157,7 +162,11 @@ struct MetaType: ::testing::Test {
             .func<entt::overload<int(int, int)>(&overloaded_func::f)>("f"_hs)
             .func<entt::overload<int(int)>(&overloaded_func::f)>("f"_hs)
             .func<entt::overload<int(int) const>(&overloaded_func::f)>("f"_hs)
-            .func<entt::overload<float(int, float)>(&overloaded_func::f)>("f"_hs);
+            .func<entt::overload<float(int, float)>(&overloaded_func::f)>("f"_hs)
+            .func<entt::overload<int(int) const>(&overloaded_func::f)>("cf"_hs)
+            .func<entt::overload<int(int)>(&overloaded_func::f)>("cf"_hs)
+            .func<entt::overload<int(int)>(&overloaded_func::f)>("ncf"_hs)
+            .func<entt::overload<int(int) const>(&overloaded_func::f)>("ncf"_hs);
 
         entt::meta_factory<property_type>{}
             .type("property"_hs)
@@ -214,7 +223,7 @@ TEST_F(MetaType, SafeWhenEmpty) {
     ASSERT_FALSE(type);
     ASSERT_EQ(type, entt::meta_type{});
     ASSERT_EQ(type.info(), entt::type_id<void>());
-    ASSERT_EQ(type.id(), entt::id_type{});
+    ASSERT_EQ(type.id(), entt::type_id<void>().hash());
     ASSERT_EQ(type.size_of(), 0u);
     ASSERT_FALSE(type.is_arithmetic());
     ASSERT_FALSE(type.is_integral());
@@ -233,9 +242,9 @@ TEST_F(MetaType, SafeWhenEmpty) {
     ASSERT_EQ(type.template_arg(0u), type);
     ASSERT_EQ(type.template_arg(1u), type);
     ASSERT_FALSE(type.can_cast(type));
-    ASSERT_FALSE(type.can_cast(entt::resolve<void>()));
-    ASSERT_FALSE(type.can_convert(type));
-    ASSERT_FALSE(type.can_convert(entt::resolve<void>()));
+    ASSERT_TRUE(type.can_cast(entt::resolve<void>()));
+    ASSERT_TRUE(type.can_convert(type));
+    ASSERT_TRUE(type.can_convert(entt::resolve<void>()));
     ASSERT_EQ(type.base().begin(), type.base().end());
     ASSERT_EQ(type.data().begin(), type.data().end());
     ASSERT_EQ(type.data("data"_hs), entt::meta_data{});
@@ -301,6 +310,15 @@ TEST_F(MetaType, IdAndInfo) {
     ASSERT_EQ(type.info(), entt::type_id<clazz>());
 }
 
+TEST_F(MetaType, Name) {
+    using namespace entt::literals;
+
+    ASSERT_EQ(entt::resolve<base>().name(), nullptr);
+    ASSERT_STREQ(entt::resolve<derived>().name(), "derived");
+    ASSERT_STREQ(entt::resolve<unsigned int>().name(), "uint");
+    ASSERT_EQ(entt::resolve<void>().name(), nullptr);
+}
+
 TEST_F(MetaType, SizeOf) {
     ASSERT_EQ(entt::resolve<void>().size_of(), 0u);
     ASSERT_EQ(entt::resolve<int>().size_of(), sizeof(int));
@@ -442,6 +460,17 @@ TEST_F(MetaType, Data) {
     ASSERT_EQ(type.data().cbegin(), type.data().cend());
 }
 
+TEST_F(MetaType, DataRecursive) {
+    using namespace entt::literals;
+
+    auto type = entt::resolve<derived>();
+    const derived instance{};
+
+    ASSERT_TRUE(type.data("value"_hs));
+    ASSERT_EQ('c', type.data("value"_hs).get(instance).cast<char>());
+    ASSERT_FALSE(type.data("value"_hs, false));
+}
+
 TEST_F(MetaType, Func) {
     using namespace entt::literals;
 
@@ -465,6 +494,17 @@ TEST_F(MetaType, Func) {
     ASSERT_EQ(type.func().cbegin(), type.func().cend());
 }
 
+TEST_F(MetaType, FuncRecursive) {
+    using namespace entt::literals;
+
+    auto type = entt::resolve<derived>();
+    const derived instance{};
+
+    ASSERT_TRUE(type.func("func"_hs));
+    ASSERT_EQ(0, type.func("func"_hs).invoke(instance).cast<int>());
+    ASSERT_FALSE(type.func("func"_hs, false));
+}
+
 TEST_F(MetaType, Invoke) {
     using namespace entt::literals;
 
@@ -543,6 +583,66 @@ TEST_F(MetaType, OverloadedFunc) {
     ASSERT_FALSE(type.invoke("f"_hs, instance, 4, 8.));
 }
 
+TEST_F(MetaType, OverloadedFuncConstFirst) {
+    using namespace entt::literals;
+
+    const auto type = entt::resolve<overloaded_func>();
+    overloaded_func instance{2};
+    entt::meta_any res{};
+
+    ASSERT_TRUE(type.func("cf"_hs));
+
+    res = type.invoke("cf"_hs, instance, 1);
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 4);
+
+    res = type.invoke("cf"_hs, std::as_const(instance), 1);
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 2);
+
+    res = type.invoke("cf"_hs, entt::meta_handle{instance}, entt::meta_any{1});
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 4);
+
+    res = type.invoke("cf"_hs, entt::meta_handle{std::as_const(instance)}, entt::meta_any{1});
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 2);
+}
+
+TEST_F(MetaType, OverloadedFuncNonConstFirst) {
+    using namespace entt::literals;
+
+    const auto type = entt::resolve<overloaded_func>();
+    overloaded_func instance{2};
+    entt::meta_any res{};
+
+    ASSERT_TRUE(type.func("ncf"_hs));
+
+    res = type.invoke("ncf"_hs, instance, 1);
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 4);
+
+    res = type.invoke("ncf"_hs, std::as_const(instance), 1);
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 2);
+
+    res = type.invoke("ncf"_hs, entt::meta_handle{instance}, entt::meta_any{1});
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 4);
+
+    res = type.invoke("ncf"_hs, entt::meta_handle{std::as_const(instance)}, entt::meta_any{1});
+
+    ASSERT_TRUE(res);
+    ASSERT_EQ(res.cast<int>(), 2);
+}
+
 TEST_F(MetaType, OverloadedFuncOrder) {
     using namespace entt::literals;
 
