@@ -1,3 +1,4 @@
+#include <cstdint>
 #include <functional>
 #include <memory>
 #include <utility>
@@ -5,34 +6,46 @@
 #include <entt/process/process.hpp>
 #include <entt/process/scheduler.hpp>
 
-struct foo_process: entt::process<foo_process, entt::scheduler::delta_type> {
-    foo_process(std::function<void()> upd, std::function<void()> abort)
-        : on_update{std::move(upd)}, on_aborted{std::move(abort)} {}
-
-    void update(delta_type, void *) const {
+class foo_process: public entt::process {
+    void update(const delta_type, void *) override {
         on_update();
     }
 
-    void aborted() const {
+    void aborted() override {
         on_aborted();
     }
 
+public:
+    using allocator_type = typename entt::process::allocator_type;
+
+    foo_process(const allocator_type &allocator, std::function<void()> upd, std::function<void()> abort)
+        : entt::process{allocator},
+          on_update{std::move(upd)},
+          on_aborted{std::move(abort)} {}
+
+private:
     std::function<void()> on_update;
     std::function<void()> on_aborted;
 };
 
-struct succeeded_process: entt::process<succeeded_process, entt::scheduler::delta_type> {
-    void update(delta_type, void *data) {
+class succeeded_process: public entt::process {
+    void update(const delta_type, void *data) override {
         ++static_cast<std::pair<int, int> *>(data)->first;
         succeed();
     }
+
+public:
+    using entt::process::process;
 };
 
-struct failed_process: entt::process<failed_process, entt::scheduler::delta_type> {
-    void update(delta_type, void *data) {
+class failed_process: public entt::process {
+    void update(const delta_type, void *data) override {
         ++static_cast<std::pair<int, int> *>(data)->second;
         fail();
     }
+
+public:
+    using entt::process::process;
 };
 
 TEST(Scheduler, Functionalities) {
@@ -47,9 +60,7 @@ TEST(Scheduler, Functionalities) {
     ASSERT_EQ(scheduler.size(), 0u);
     ASSERT_TRUE(scheduler.empty());
 
-    scheduler.attach<foo_process>(
-        [&updated]() { updated = true; },
-        [&aborted]() { aborted = true; });
+    scheduler.attach<foo_process>([&updated]() { updated = true; }, [&aborted]() { aborted = true; });
 
     ASSERT_NE(scheduler.size(), 0u);
     ASSERT_FALSE(scheduler.empty());
@@ -74,7 +85,7 @@ TEST(Scheduler, Swap) {
     entt::scheduler other{};
     int counter{};
 
-    scheduler.attach([&counter](auto &&...) { ++counter; });
+    scheduler.attach([&counter](entt::process &, std::uint32_t, void *) { ++counter; });
 
     ASSERT_EQ(scheduler.size(), 1u);
     ASSERT_EQ(other.size(), 0u);
@@ -96,22 +107,37 @@ TEST(Scheduler, Swap) {
     ASSERT_EQ(counter, 2);
 }
 
-TEST(Scheduler, Then) {
+TEST(Scheduler, SharedFromThis) {
+    entt::scheduler scheduler{};
+    auto &process = scheduler.attach<succeeded_process>();
+    const auto &then = process.then<failed_process>();
+    auto other = process.shared_from_this();
+
+    ASSERT_TRUE(other);
+    ASSERT_NE(&process, &then);
+    ASSERT_EQ(&process, other.get());
+    ASSERT_EQ(process.get_allocator(), scheduler.get_allocator());
+    ASSERT_EQ(process.get_allocator(), other->get_allocator());
+    ASSERT_EQ(then.get_allocator(), scheduler.get_allocator());
+}
+
+TEST(Scheduler, AttachThen) {
     entt::scheduler scheduler{};
     std::pair<int, int> counter{};
 
-    scheduler
-        // failing process with successor
-        .attach<succeeded_process>()
+    // failing process with successor
+    scheduler.attach<succeeded_process>()
         .then<succeeded_process>()
         .then<failed_process>()
+        .then<succeeded_process>();
+
+    // failing process without successor
+    scheduler.attach<succeeded_process>()
         .then<succeeded_process>()
-        // failing process without successor
-        .attach<succeeded_process>()
-        .then<succeeded_process>()
-        .then<failed_process>()
-        // non-failing process
-        .attach<succeeded_process>()
+        .then<failed_process>();
+
+    // non-failing process
+    scheduler.attach<succeeded_process>()
         .then<succeeded_process>();
 
     while(!scheduler.empty()) {
@@ -128,19 +154,18 @@ TEST(Scheduler, Functor) {
     bool first_functor = false;
     bool second_functor = false;
 
-    auto attach = [&first_functor](auto, void *, auto resolve, auto) {
-        ASSERT_FALSE(first_functor);
-        first_functor = true;
-        resolve();
-    };
-
-    auto then = [&second_functor](auto, void *, auto, auto reject) {
-        ASSERT_FALSE(second_functor);
-        second_functor = true;
-        reject();
-    };
-
-    scheduler.attach(std::move(attach)).then(std::move(then)).then([](auto...) { FAIL(); });
+    scheduler
+        .attach([&first_functor](entt::process &proc, std::uint32_t, void *) {
+            ASSERT_FALSE(first_functor);
+            first_functor = true;
+            proc.succeed();
+        })
+        .then([&second_functor](entt::process &proc, std::uint32_t, void *) {
+            ASSERT_FALSE(second_functor);
+            second_functor = true;
+            proc.fail();
+        })
+        .then([](entt::process &, std::uint32_t, void *) { FAIL(); });
 
     while(!scheduler.empty()) {
         scheduler.update(0);
@@ -155,9 +180,9 @@ TEST(Scheduler, SpawningProcess) {
     entt::scheduler scheduler{};
     std::pair<int, int> counter{};
 
-    scheduler.attach([&scheduler](auto, void *, auto resolve, auto) {
+    scheduler.attach([&scheduler](entt::process &proc, std::uint32_t, void *) {
         scheduler.attach<succeeded_process>().then<failed_process>();
-        resolve();
+        proc.succeed();
     });
 
     while(!scheduler.empty()) {
@@ -175,7 +200,7 @@ TEST(Scheduler, CustomAllocator) {
     ASSERT_EQ(scheduler.get_allocator(), allocator);
     ASSERT_FALSE(scheduler.get_allocator() != allocator);
 
-    scheduler.attach([](auto &&...) {});
+    scheduler.attach([](entt::process &, std::uint32_t, void *) {});
     const decltype(scheduler) other{std::move(scheduler), allocator};
 
     ASSERT_EQ(other.size(), 1u);
