@@ -8,20 +8,20 @@
 struct base {
     virtual ~base() = default;
 
-    [[nodiscard]] virtual const entt::type_info &type() const noexcept {
+    [[nodiscard]] virtual const entt::type_info &info() const noexcept {
         return entt::type_id<base>();
     }
 };
 
 struct derived: base {
-    [[nodiscard]] const entt::type_info &type() const noexcept override {
+    [[nodiscard]] const entt::type_info &info() const noexcept override {
         return entt::type_id<derived>();
     }
 };
 
 template<typename Type, typename Other>
 entt::resource<Type> dynamic_resource_cast(const entt::resource<Other> &other) {
-    if(other->type() == entt::type_id<Type>()) {
+    if(other->info() == entt::type_id<Type>()) {
         return entt::resource<Type>{other, static_cast<Type &>(*other)};
     }
 
@@ -42,7 +42,7 @@ TEST(Resource, Functionalities) {
     ASSERT_EQ(other.operator->(), value.get());
     ASSERT_EQ(&static_cast<derived &>(other), value.get());
     ASSERT_EQ(&*other, value.get());
-    ASSERT_EQ(other.handle().use_count(), 2l);
+    ASSERT_EQ(other.handle().use_count(), 3l);
 
     entt::resource<derived> copy{resource};
     entt::resource<derived> move{std::move(other)};
@@ -132,12 +132,12 @@ TEST(Resource, ConstNonConstAndAllInBetween) {
     ASSERT_TRUE(copy);
     ASSERT_EQ(copy, resource);
     ASSERT_NE(copy, entt::resource<derived>{});
-    ASSERT_EQ(copy.handle().use_count(), 3);
+    ASSERT_EQ(copy.handle().use_count(), 4);
 
     ASSERT_TRUE(move);
     ASSERT_EQ(move, resource);
     ASSERT_NE(move, entt::resource<derived>{});
-    ASSERT_EQ(move.handle().use_count(), 3);
+    ASSERT_EQ(move.handle().use_count(), 4);
 
     copy = resource;
     move = std::move(resource);
@@ -148,7 +148,7 @@ TEST(Resource, ConstNonConstAndAllInBetween) {
 
     ASSERT_TRUE(copy);
     ASSERT_TRUE(move);
-    ASSERT_EQ(copy.handle().use_count(), 2);
+    ASSERT_EQ(copy.handle().use_count(), 3);
 }
 
 TEST(Resource, DynamicResourceHandleCast) {
@@ -156,20 +156,20 @@ TEST(Resource, DynamicResourceHandleCast) {
     entt::resource<const base> other = resource;
 
     ASSERT_TRUE(other);
-    ASSERT_EQ(resource.handle().use_count(), 2);
+    ASSERT_EQ(resource.handle().use_count(), 3);
     ASSERT_EQ(resource, other);
 
     entt::resource<const derived> cast = dynamic_resource_cast<const derived>(other);
 
     ASSERT_TRUE(cast);
-    ASSERT_EQ(resource.handle().use_count(), 3);
+    ASSERT_EQ(resource.handle().use_count(), 4);
     ASSERT_EQ(resource, cast);
 
     other = entt::resource<base>{std::make_shared<base>()};
     cast = dynamic_resource_cast<const derived>(other);
 
     ASSERT_FALSE(cast);
-    ASSERT_EQ(resource.handle().use_count(), 1);
+    ASSERT_EQ(resource.handle().use_count(), 2);
 }
 
 TEST(Resource, Comparison) {
