@@ -1,7 +1,8 @@
-#include <entt/core/attribute.h>
+#include <entt/config/config.h>
 #include "../../../common/boxed_type.h"
 #include "../../../common/emitter.h"
 #include "../../../common/empty.h"
+#include "lib.h"
 
 ENTT_API void emit(test::emitter &emitter) {
     emitter.publish(test::empty{});
