@@ -1,9 +1,10 @@
-#include <entt/core/attribute.h>
+#include <entt/config/config.h>
 #include <entt/entity/mixin.hpp>
 #include <entt/entity/registry.hpp>
 #include <entt/entity/view.hpp>
 #include "../../../common/boxed_type.h"
 #include "../../../common/empty.h"
+#include "lib.h"
 
 template class entt::basic_registry<entt::entity>;
 
