@@ -1,8 +1,7 @@
 #include <gtest/gtest.h>
-#include <entt/core/attribute.h>
+#include <entt/config/config.h>
 #include "../types.h"
-
-ENTT_API const void *filter(const view_type &);
+#include "lib.h"
 
 TEST(Lib, View) {
     view_type view{};
